@@ -200,10 +200,45 @@ our %EXPORT_TAGS = ( 'all' => [ qw(
         RPI_V2_GPIO_P1_23
         RPI_V2_GPIO_P1_24
         RPI_V2_GPIO_P1_26
+        RPI_V2_GPIO_P1_29
+        RPI_V2_GPIO_P1_31
+        RPI_V2_GPIO_P1_32
+        RPI_V2_GPIO_P1_33
+        RPI_V2_GPIO_P1_35
+        RPI_V2_GPIO_P1_36
+        RPI_V2_GPIO_P1_37
+        RPI_V2_GPIO_P1_38
+        RPI_V2_GPIO_P1_40
         RPI_V2_GPIO_P5_03
         RPI_V2_GPIO_P5_04
         RPI_V2_GPIO_P5_05
         RPI_V2_GPIO_P5_06
+        RPI_BPLUS_GPIO_J8_03
+        RPI_BPLUS_GPIO_J8_05
+        RPI_BPLUS_GPIO_J8_07
+        RPI_BPLUS_GPIO_J8_08
+        RPI_BPLUS_GPIO_J8_10
+        RPI_BPLUS_GPIO_J8_11
+        RPI_BPLUS_GPIO_J8_12
+        RPI_BPLUS_GPIO_J8_13
+        RPI_BPLUS_GPIO_J8_15
+        RPI_BPLUS_GPIO_J8_16
+        RPI_BPLUS_GPIO_J8_18
+        RPI_BPLUS_GPIO_J8_19
+        RPI_BPLUS_GPIO_J8_21
+        RPI_BPLUS_GPIO_J8_22
+        RPI_BPLUS_GPIO_J8_23
+        RPI_BPLUS_GPIO_J8_24
+        RPI_BPLUS_GPIO_J8_26
+        RPI_BPLUS_GPIO_J8_29
+        RPI_BPLUS_GPIO_J8_31
+        RPI_BPLUS_GPIO_J8_32
+        RPI_BPLUS_GPIO_J8_33
+        RPI_BPLUS_GPIO_J8_35
+        RPI_BPLUS_GPIO_J8_36
+        RPI_BPLUS_GPIO_J8_37
+        RPI_BPLUS_GPIO_J8_38
+        RPI_BPLUS_GPIO_J8_40
 ) ] );
 
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
@@ -391,13 +426,48 @@ our @EXPORT = qw(
         RPI_V2_GPIO_P1_23
         RPI_V2_GPIO_P1_24
         RPI_V2_GPIO_P1_26
+        RPI_V2_GPIO_P1_29
+        RPI_V2_GPIO_P1_31
+        RPI_V2_GPIO_P1_32
+        RPI_V2_GPIO_P1_33
+        RPI_V2_GPIO_P1_35
+        RPI_V2_GPIO_P1_36
+        RPI_V2_GPIO_P1_37
+        RPI_V2_GPIO_P1_38
+        RPI_V2_GPIO_P1_40
         RPI_V2_GPIO_P5_03
         RPI_V2_GPIO_P5_04
         RPI_V2_GPIO_P5_05
         RPI_V2_GPIO_P5_06
+        RPI_BPLUS_GPIO_J8_03
+        RPI_BPLUS_GPIO_J8_05
+        RPI_BPLUS_GPIO_J8_07
+        RPI_BPLUS_GPIO_J8_08
+        RPI_BPLUS_GPIO_J8_10
+        RPI_BPLUS_GPIO_J8_11
+        RPI_BPLUS_GPIO_J8_12
+        RPI_BPLUS_GPIO_J8_13
+        RPI_BPLUS_GPIO_J8_15
+        RPI_BPLUS_GPIO_J8_16
+        RPI_BPLUS_GPIO_J8_18
+        RPI_BPLUS_GPIO_J8_19
+        RPI_BPLUS_GPIO_J8_21
+        RPI_BPLUS_GPIO_J8_22
+        RPI_BPLUS_GPIO_J8_23
+        RPI_BPLUS_GPIO_J8_24
+        RPI_BPLUS_GPIO_J8_26
+        RPI_BPLUS_GPIO_J8_29
+        RPI_BPLUS_GPIO_J8_31
+        RPI_BPLUS_GPIO_J8_32
+        RPI_BPLUS_GPIO_J8_33
+        RPI_BPLUS_GPIO_J8_35
+        RPI_BPLUS_GPIO_J8_36
+        RPI_BPLUS_GPIO_J8_37
+        RPI_BPLUS_GPIO_J8_38
+        RPI_BPLUS_GPIO_J8_40
 );
 
-our $VERSION = '1.9';
+our $VERSION = '1.10';
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
